@@ -19,8 +19,8 @@ class Notifications(Client):
         /notifications/v1/destinations/{destinationId}
     """
 
-    def __init__(self, marketplace=Marketplaces.US, *, refresh_token=None, account='default'):
-        super().__init__(marketplace, refresh_token, account)
+    def __init__(self, marketplace=Marketplaces.US, *, refresh_token=None, account='default', credentials=None):
+        super().__init__(marketplace, refresh_token, account, credentials)
 
     @deprecated
     def add_subscription(self, notification_type: NotificationType or str, **kwargs):
