@@ -5,8 +5,8 @@ from sp_api.base import Client, Marketplaces, sp_endpoint
 
 
 class Products(Client):
-    def __init__(self, marketplace=Marketplaces.US, *, refresh_token=None, account='default'):
-        super().__init__(marketplace, refresh_token, account)
+    def __init__(self, marketplace=Marketplaces.US, *, refresh_token=None, account='default', credentials=None):
+        super().__init__(marketplace, refresh_token, account, credentials)
 
     def get_product_pricing_for_skus(self, seller_sku_list, **kwargs):
         """
