@@ -19,8 +19,9 @@ class AccessTokenClient(BaseClient):
     grant_type = 'refresh_token'
     path = '/auth/o2/token'
 
-    def __init__(self, refresh_token=None, account='default'):
-        super().__init__(account)
+    def __init__(self, refresh_token=None, account='default', credentials=None):
+        print('access', credentials)
+        super().__init__(account, credentials)
         self.cred = Credentials(refresh_token, self.credentials)
 
     def get_auth(self) -> AccessTokenResponse:
